==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/sl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Podano ime je predolgo",
    "The given web address is too long" : "Podan spletni naslov je predolg",
    "The given web address is not a valid URL" : "Podan spletni naslov ni veljaven naslov URL.",
    "The given legal notice address is too long" : "Podan naslov pravnega obvestila je predolg",
    "The given legal notice address is not a valid URL" : "Podan naslov pravnega obvestila ni veljaven naslov URL.",
    "The given privacy policy address is too long" : "Podan naslov pravil zasebnosti je predolg",
    "The given privacy policy address is not a valid URL" : "Podan naslov pravil zasebnosti ni veljaven naslov URL.",
    "The given slogan is too long" : "Podan slogan je predolg",
    "The given color is invalid" : "Podana koda barve ni veljavna",
    "Disable-user-theming should be true or false" : "Možnost za omogočanje uporabniške teme mora biti prav ali napak.",
    "Saved" : "Shranjeno",
    "The file was uploaded" : "Datoteka je  uspešno poslana",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo upload_max_filesize v datoteke php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki jo določa parameter največje dovoljene velikosti MAX_FILE_SIZE v zapisu HTML.",
    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
    "No file was uploaded" : "Datoteka še ni bila poslana",
    "Missing a temporary folder" : "Manjka začasna mapa",
    "Could not write file to disk" : "Datoteke ni mogoče zapisati na disk",
    "A PHP extension stopped the file upload" : "Razširitev PHP je onemogočila pošiljanje datoteke",
    "No file uploaded" : "Ni poslanih datotek",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Tema po meri je že določena. S spreminjanjem nastavitev bodo stari podatki prepisani.",
    "Theming" : "Teme",
    "Appearance and accessibility" : "Videz in dostopnost",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Modul PHP »imagick« ni omogočen, je pa zagnan program za oblikovanje vmesnika. Za pravilno delovanje ustvarjanja ikon je treba modul namestiti in omogočiti.",
    "Dark theme with high contrast mode" : "Temna tema v kontrastnem načinu",
    "Enable dark high contrast mode" : "Omogoči temno kontrastno temo",
    "Similar to the high contrast mode, but with dark colours." : "Podobno temni kontrastni temi, a s temnimi barvami",
    "Dark theme" : "Temna tema",
    "Enable dark theme" : "Omogoči temno temo",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Temna tema za sproščanje oči z zmanjševanjem splošne osvetljenosti in svetlosti prikaza.",
    "System default theme" : "Sistemska privzeta tema",
    "Enable the system default" : "Omogoči sistemsko privzeto temo",
    "Using the default system appearance." : "V uporabi je privzet sistemski videz.",
    "Dyslexia font" : "Pisava za posameznike z disleksijo",
    "Enable dyslexia font" : "Omogoči pisavo za posameznike z disleksijo",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Pisava OpenDyslexic je prosta pisava, zasnovana in oblikovana za posameznike z disleksijo. Olajša nekatere splošne težave pri branju.",
    "High contrast mode" : "Visoko kontrastna tema",
    "Enable high contrast mode" : "Omogoči visoko kontrastno temo",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Visoko kontrastna tema omogoča nazornejši prikaz vmesnika. Pogled se poenostavi, poveča pa se jasnost prikaza.",
    "Light theme" : "Svetla tema",
    "Enable the default light theme" : "Omogoči privzeto svetlo temo",
    "The default light appearance." : "Privzet svetel videz okolja.",
    "Legal notice" : "Pravno obvestilo",
    "Privacy policy" : "Pravila zasebnosti",
    "Adjust the Nextcloud theme" : "Prilagajanje teme Nextcloud",
    "Name" : "Ime",
    "Web link" : "Spletni naslov",
    "a safe home for all your data" : "varno okolje za vaše podatke",
    "Slogan" : "Slogan",
    "Primary color" : "Prva barva",
    "Legal notice link" : "Povezava do pravnega obvestila",
    "Privacy policy link" : "Povezava do pravil zasebnosti",
    "Header logo" : "Logotip glave",
    "Upload new header logo" : "Pošlji nov logotip glave",
    "Favicon" : "Ikona zaznamka",
    "Upload new favicon" : "Pošli novo ikono zaznamka",
    "User settings" : "Uporabniške nastavitve",
    "Disable user theming" : "Onemogoči uporabniške teme",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Čeprav je mogoče izbirati in prilagajati vmesnik, lahko uporabniki spremenijo ozadje in barve. Če želite vsiliti prilagoditve, preklopite možnost na omogočeno.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teme omogočajo enostavno prilagajanje videza in občutka vmesnika in podprtih programskih odjemalcev. Prilagoditve bodo spremenjene za vse uporabnike sistema.",
    "Background color" : "Barva ozadja",
    "Upload new logo" : "Pošlji nov logotip",
    "Logo" : "Logotip",
    "Upload new background and login image" : "Pošlji novo sliko ozadja in prijavno sliko",
    "Background and login image" : "Ozadje in prijavna slika",
    "Advanced options" : "Napredne možnosti",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Z namestitvijo razširitve ImageMagick PHP s podporo za zapis SVG je mogoče samodejno ustvariti ikone zaznamka na podlagi določenega logotipa in barve.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Če naletite na težave, ne odlašajte in takoj pošljite poročilo na {issuetracker}sledilnik{linkend}, če želite sodelovati, pa se pridružite {designteam}skupini oblikovalcev{linkend}!",
    "Customization has been disabled by your administrator" : "Prilagajanje je skrbniško onemogočeno.",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V nekaterih primerih delovanje tipkovnih bližnjic motijo orodja za dostopnost. Za pravilno delo z orodji je mogoče vse tipkovne bližnjice onemogočiti, s tem pa tudi vse bližnjice programov.",
    "Disable all keyboard shortcuts" : "Onemogoči vse tipkovne bližnjice",
    "Move up" : "Premakni navzgor",
    "Move down" : "Premakni navzdol",
    "Select a background from your files" : "Izbor ozadja med datotekami",
    "Select background" : "Izbor ozadja",
    "No background has been selected" : "Ni izbranega ozadja",
    "Custom background" : "Ozadje po meri",
    "Plain background" : "Enostavno ozadje",
    "Default background" : "Privzeto ozadje",
    "Theme selection is enforced" : "Izbira teme je vsiljena",
    "Navigation bar settings" : "Nastavitve vrstice programov",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Nastaviti je mogoče zaporedje programov v vrstici. Na prvem mestu je privzet program, ki se zažene ob prijavi oziroma ob kliku na logo oblaka.",
    "The default app can not be changed because it was configured by the administrator." : "Privzetega programa ni mogoče spremeniti, ker je nastavljen sistemsko.",
    "Could not set primary color" : "Prve barve ni mogoče nastaviti",
    "Reset primary color" : "Ponastavi prvo barvo",
    "Default app" : "Privzet program",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Privzeti program je tisti, ki se odpre kot prva stran po prijavi oziroma ob kliku na logo oblaka.",
    "Use custom default app" : "Uporabi privzeti program po meri",
    "Global default app" : "Splošni privzeti program",
    "Global default apps" : "Splošni privzeti programi",
    "Select a custom color" : "Izbor barve po meri",
    "Reset to default" : "Ponastavi na privzeto",
    "Upload" : "Pošlji",
    "Remove background image" : "Odstrani sliko ozadja",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Enostaven dostop do možnosti je za nas zelo pomemben. Sledimo spletnim standardom in preverjamo, da je vmesnik uporaben tudi brez uporabe miške in brez podporne programske opreme, kot so zaslonski bralniki in podobno. Zagotavljamo skladnost s smernicami {guidelines}Dostopnosti spletne vsebine{linkend} 2.1 na ravni AA, pri visoko kontrastni temi pa tudi na ravni AAA."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/sl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Podano ime je predolgo",
    "The given web address is too long" : "Podan spletni naslov je predolg",
    "The given web address is not a valid URL" : "Podan spletni naslov ni veljaven naslov URL.",
    "The given legal notice address is too long" : "Podan naslov pravnega obvestila je predolg",
    "The given legal notice address is not a valid URL" : "Podan naslov pravnega obvestila ni veljaven naslov URL.",
    "The given privacy policy address is too long" : "Podan naslov pravil zasebnosti je predolg",
    "The given privacy policy address is not a valid URL" : "Podan naslov pravil zasebnosti ni veljaven naslov URL.",
    "The given slogan is too long" : "Podan slogan je predolg",
    "The given color is invalid" : "Podana koda barve ni veljavna",
    "Saved" : "Shranjeno",
    "The file was uploaded" : "Datoteka je  uspešno poslana",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo upload_max_filesize v datoteke php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki jo določa parameter največje dovoljene velikosti MAX_FILE_SIZE v zapisu HTML.",
    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
    "No file was uploaded" : "Datoteka še ni bila poslana",
    "Missing a temporary folder" : "Manjka začasna mapa",
    "Could not write file to disk" : "Datoteke ni mogoče zapisati na disk",
    "A PHP extension stopped the file upload" : "Razširitev PHP je onemogočila pošiljanje datoteke",
    "No file uploaded" : "Ni poslanih datotek",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Tema po meri je že določena. S spreminjanjem nastavitev bodo stari podatki prepisani.",
    "Theming" : "Teme",
    "Appearance and accessibility" : "Videz in dostopnost",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Modul PHP »imagick« ni omogočen, je pa zagnan program za oblikovanje vmesnika. Za pravilno delovanje ustvarjanja ikon je treba modul namestiti in omogočiti.",
    "Dark theme with high contrast mode" : "Temna tema v kontrastnem načinu",
    "Enable dark high contrast mode" : "Omogoči temno kontrastno temo",
    "Similar to the high contrast mode, but with dark colours." : "Podobno temni kontrastni temi, a s temnimi barvami",
    "Dark theme" : "Temna tema",
    "Enable dark theme" : "Omogoči temno temo",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Temna tema za sproščanje oči z zmanjševanjem splošne osvetljenosti in svetlosti prikaza.",
    "System default theme" : "Sistemska privzeta tema",
    "Enable the system default" : "Omogoči sistemsko privzeto temo",
    "Using the default system appearance." : "V uporabi je privzet sistemski videz.",
    "Dyslexia font" : "Pisava za posameznike z disleksijo",
    "Enable dyslexia font" : "Omogoči pisavo za posameznike z disleksijo",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Pisava OpenDyslexic je prosta pisava, zasnovana in oblikovana za posameznike z disleksijo. Olajša nekatere splošne težave pri branju.",
    "High contrast mode" : "Visoko kontrastna tema",
    "Enable high contrast mode" : "Omogoči visoko kontrastno temo",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Visoko kontrastna tema omogoča nazornejši prikaz vmesnika. Pogled se poenostavi, poveča pa se jasnost prikaza.",
    "Light theme" : "Svetla tema",
    "Enable the default light theme" : "Omogoči privzeto svetlo temo",
    "The default light appearance." : "Privzet svetel videz okolja.",
    "Legal notice" : "Pravno obvestilo",
    "Privacy policy" : "Pravila zasebnosti",
    "Adjust the Nextcloud theme" : "Prilagajanje teme Nextcloud",
    "Navigation bar settings" : "Nastavitve vrstice programov",
    "Default app" : "Privzet program",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Privzeti program je tisti, ki se odpre kot prva stran po prijavi oziroma ob kliku na logo oblaka.",
    "Use custom default app" : "Uporabi privzeti program po meri",
    "Global default app" : "Splošni privzeti program",
    "Global default apps" : "Splošni privzeti programi",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teme omogočajo enostavno prilagajanje videza in občutka vmesnika in podprtih programskih odjemalcev. Prilagoditve bodo spremenjene za vse uporabnike sistema.",
    "Name" : "Ime",
    "Web link" : "Spletni naslov",
    "Slogan" : "Slogan",
    "a safe home for all your data" : "varno okolje za vaše podatke",
    "Legal notice link" : "Povezava do pravnega obvestila",
    "Privacy policy link" : "Povezava do pravil zasebnosti",
    "Primary color" : "Prva barva",
    "Background color" : "Barva ozadja",
    "Remove background image" : "Odstrani sliko ozadja",
    "Favicon" : "Ikona zaznamka",
    "Logo" : "Logotip",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Čeprav je mogoče izbirati in prilagajati vmesnik, lahko uporabniki spremenijo ozadje in barve. Če želite vsiliti prilagoditve, preklopite možnost na omogočeno.",
    "Disable user theming" : "Onemogoči uporabniške teme",
    "Move up" : "Premakni navzgor",
    "Move down" : "Premakni navzdol",
    "Theme selection is enforced" : "Izbira teme je vsiljena",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Nastaviti je mogoče zaporedje programov v vrstici. Na prvem mestu je privzet program, ki se zažene ob prijavi oziroma ob kliku na logo oblaka.",
    "The default app can not be changed because it was configured by the administrator." : "Privzetega programa ni mogoče spremeniti, ker je nastavljen sistemsko.",
    "Select a background from your files" : "Izbor ozadja med datotekami",
    "Select background" : "Izbor ozadja",
    "Custom background" : "Ozadje po meri",
    "Plain background" : "Enostavno ozadje",
    "Default background" : "Privzeto ozadje",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V nekaterih primerih delovanje tipkovnih bližnjic motijo orodja za dostopnost. Za pravilno delo z orodji je mogoče vse tipkovne bližnjice onemogočiti, s tem pa tudi vse bližnjice programov.",
    "Disable all keyboard shortcuts" : "Onemogoči vse tipkovne bližnjice",
    "Could not set primary color" : "Prve barve ni mogoče nastaviti",
    "Reset primary color" : "Ponastavi prvo barvo",
    "Reset to default" : "Ponastavi na privzeto",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Če naletite na težave, ne odlašajte in takoj pošljite poročilo na {issuetracker}sledilnik{linkend}, če želite sodelovati, pa se pridružite {designteam}skupini oblikovalcev{linkend}!",
    "Customization has been disabled by your administrator" : "Prilagajanje je skrbniško onemogočeno.",
    "Disable-user-theming should be true or false" : "Možnost za omogočanje uporabniške teme mora biti prav ali napak.",
    "Header logo" : "Logotip glave",
    "Upload new header logo" : "Pošlji nov logotip glave",
    "Upload new favicon" : "Pošli novo ikono zaznamka",
    "User settings" : "Uporabniške nastavitve",
    "Upload new logo" : "Pošlji nov logotip",
    "Upload new background and login image" : "Pošlji novo sliko ozadja in prijavno sliko",
    "Background and login image" : "Ozadje in prijavna slika",
    "Advanced options" : "Napredne možnosti",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Z namestitvijo razširitve ImageMagick PHP s podporo za zapis SVG je mogoče samodejno ustvariti ikone zaznamka na podlagi določenega logotipa in barve.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Enostaven dostop do možnosti je za nas zelo pomemben. Sledimo spletnim standardom in preverjamo, da je vmesnik uporaben tudi brez uporabe miške in brez podporne programske opreme, kot so zaslonski bralniki in podobno. Zagotavljamo skladnost s smernicami {guidelines}Dostopnosti spletne vsebine{linkend} 2.1 na ravni AA, pri visoko kontrastni temi pa tudi na ravni AAA.",
    "No background has been selected" : "Ni izbranega ozadja",
    "Select a custom color" : "Izbor barve po meri",
    "Upload" : "Pošlji"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
